class exprt;
class typet;

void expand_map(exprt &expr);

void mapping_to_lambda(const typet &type, exprt &expr);

